@@ -396,14 +396,14 @@ class Observation(models.Model):
     transmitter_invert = models.BooleanField(default=False)
     transmitter_baud = models.FloatField(validators=[MinValueValidator(0)], blank=True, null=True)
     transmitter_created = models.DateTimeField(default=now)
-    station_alt = models.PositiveIntegerField(null=True)
+    station_alt = models.PositiveIntegerField(null=True, blank=True)
     station_lat = models.FloatField(
-        validators=[MaxValueValidator(90), MinValueValidator(-90)], null=True
+        validators=[MaxValueValidator(90), MinValueValidator(-90)], null=True, blank=True
     )
     station_lng = models.FloatField(
-        validators=[MaxValueValidator(180), MinValueValidator(-180)], null=True
+        validators=[MaxValueValidator(180), MinValueValidator(-180)], null=True, blank=True
     )
-    station_antennas = models.TextField(null=True)
+    station_antennas = models.TextField(null=True, blank=True)
 
     objects = ObservationManager.as_manager()
 
@@ -508,7 +508,7 @@ class Observation(models.Model):
         """Return url for observation's audio file"""
         if self.has_audio:
             if self.archive_url:
-                return 'archived'
+                return self.archive_url
             return self.payload.url
         return ''
 
